#include <tag_c.h>
#include <stdio.h>
#include <stdlib.h>

#include "musicbox.h"

void
clear_tags ()
{
	f.artist = "";
	f.title = "";
	f.album = "";
	f.year = 0;
	f.track = 0;
	f.genre = "";
	f.comment = "";

	gtk_entry_set_text (GTK_ENTRY
			    (glade_xml_get_widget (xml, "entry_artist")), "");
	gtk_entry_set_text (GTK_ENTRY
			    (glade_xml_get_widget (xml, "entry_title")), "");
	gtk_entry_set_text (GTK_ENTRY
			    (glade_xml_get_widget (xml, "entry_album")), "");
	gtk_spin_button_set_value (GTK_SPIN_BUTTON
				   (glade_xml_get_widget (xml, "spin_year")),
				   0);
	gtk_spin_button_set_value (GTK_SPIN_BUTTON
				   (glade_xml_get_widget (xml, "spin_track")),
				   0);
	gtk_entry_set_text (GTK_ENTRY
			    (glade_xml_get_widget (xml, "entry_genre")), "");
	gtk_entry_set_text (GTK_ENTRY
			    (glade_xml_get_widget (xml, "entry_comment")),
			    "");
}

void
load_file (gchar * filepath)
{
	gchar **name;
	int i = 0;

	read_tag (filepath);

	if (f.artist)
		gtk_entry_set_text (GTK_ENTRY
				    (glade_xml_get_widget
				     (xml, "entry_artist")),
				    (const gchar *) f.artist);
	if (f.title)
		gtk_entry_set_text (GTK_ENTRY
				    (glade_xml_get_widget
				     (xml, "entry_title")),
				    (const gchar *) f.title);
	if (f.album)
		gtk_entry_set_text (GTK_ENTRY
				    (glade_xml_get_widget
				     (xml, "entry_album")),
				    (const gchar *) f.album);
	if (f.year)
		gtk_spin_button_set_value (GTK_SPIN_BUTTON
					   (glade_xml_get_widget
					    (xml, "spin_year")),
					   (double) f.year);
	if (f.track)
		gtk_spin_button_set_value (GTK_SPIN_BUTTON
					   (glade_xml_get_widget
					    (xml, "spin_track")),
					   (double) f.track);
	if (f.genre)
		gtk_entry_set_text (GTK_ENTRY
				    (glade_xml_get_widget
				     (xml, "entry_genre")),
				    (const gchar *) f.genre);
	if (f.comment)
		gtk_entry_set_text (GTK_ENTRY
				    (glade_xml_get_widget
				     (xml, "entry_comment")),
				    (const gchar *) f.comment);
	f.filepath = filepath;

	name = g_path_get_basename(f.filepath);
	gtk_label_set_text (GTK_LABEL
			    (glade_xml_get_widget (xml, "label_filename")),
			    (gchar *) name);
	
	gtk_widget_set_sensitive(GTK_WIDGET(glade_xml_get_widget(xml,"button_apply")),TRUE);
	gtk_widget_set_sensitive(GTK_WIDGET(glade_xml_get_widget(xml,"button_clear")),TRUE);
}

void
init_filetag (FileTag * ft)
{
	ft->title = "";
	ft->artist = "";
	ft->album = "";
	ft->year = 0;
	ft->genre = "";
	ft->track = 0;
	ft->comment = "";
	ft->filepath = "";
}

void
read_tag (gchar * filepath)
{
	TagLib_File *file;
	TagLib_Tag *tag;

	init_filetag (&f);
	file = taglib_file_new ((char *) filepath);
	tag = taglib_file_tag (file);
	f.title = (gchar *) taglib_tag_title (tag);
	f.artist = (gchar *) taglib_tag_artist (tag);
	f.album = (gchar *) taglib_tag_album (tag);
	f.year = (double) taglib_tag_year (tag);
	f.genre = (gchar *) taglib_tag_genre (tag);
	f.track = (double) taglib_tag_track (tag);
	f.comment = (gchar *) taglib_tag_comment (tag);
	f.filepath = filepath;

	taglib_file_free (file);
}

void
write_tag ()
{
	TagLib_File *file;
	TagLib_Tag *tag;

	printf ("%s\n", f.filepath);
	file = taglib_file_new ((char *) f.filepath);
	tag = taglib_file_tag (file);

	taglib_tag_set_title (tag,
			      (const char *)
			      gtk_entry_get_text (GTK_ENTRY
						  (glade_xml_get_widget
						   (xml, "entry_title"))));
	taglib_tag_set_artist (tag,
			       (const char *)
			       gtk_entry_get_text (GTK_ENTRY
						   (glade_xml_get_widget
						    (xml, "entry_artist"))));
	taglib_tag_set_album (tag,
			      (const char *)
			      gtk_entry_get_text (GTK_ENTRY
						  (glade_xml_get_widget
						   (xml, "entry_album"))));
	taglib_tag_set_year (tag,
			     (int)
			     gtk_spin_button_get_value (GTK_SPIN_BUTTON
							(glade_xml_get_widget
							 (xml,
							  "spin_year"))));
	taglib_tag_set_genre (tag,
			      (const char *)
			      gtk_entry_get_text (GTK_ENTRY
						  (glade_xml_get_widget
						   (xml, "entry_genre"))));
	taglib_tag_set_track (tag,
			      (int)
			      gtk_spin_button_get_value (GTK_SPIN_BUTTON
							 (glade_xml_get_widget
							  (xml,
							   "spin_track"))));
	taglib_tag_set_comment (tag,
				(const char *)
				gtk_entry_get_text (GTK_ENTRY
						    (glade_xml_get_widget
						     (xml,
						      "entry_comment"))));
	taglib_file_save (file);

	taglib_file_free (file);
}
